package com.aucma.dms.controller;

import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.core.page.TableDataInfo;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.dms.domain.DmsRecordLube;
import com.aucma.dms.service.IDmsRecordLubeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;




/**
 * 润滑记录Controller
 *
 * @author Open Platform
 * @date 2024-01-12
 */
@RestController
@RequestMapping("/dms/dmsRecordLube")
public class DmsRecordLubeController extends BaseController
{

    @Autowired
    private IDmsRecordLubeService dmsRecordLubeService;

    /**
     * 查询润滑记录列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsRecordLube:list')" )
    @GetMapping("/list")
    public TableDataInfo list(DmsRecordLube dmsRecordLube)
    {
        startPage();
        List<DmsRecordLube> list = dmsRecordLubeService.selectDmsRecordLubeList(dmsRecordLube);
        return getDataTable(list);
    }

    /**
     * 导出润滑记录列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsRecordLube:export')" )
    ////@Log(title = "润滑记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsRecordLube dmsRecordLube)
    {
        List<DmsRecordLube> list = dmsRecordLubeService.selectDmsRecordLubeList(dmsRecordLube);
        ExcelUtil<DmsRecordLube> util = new ExcelUtil<DmsRecordLube>(DmsRecordLube.class);
        util.exportExcel(response, list, "润滑记录数据");
    }

    /**
     * 获取润滑记录详细信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsRecordLube:remove')" )
    @GetMapping(value = "/{recordLubeId}")
    public AjaxResult getInfo(@PathVariable("recordLubeId") Long recordLubeId)
    {
        return success(dmsRecordLubeService.selectDmsRecordLubeByRecordLubeId(recordLubeId));
    }

    /**
     * 新增润滑记录
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsRecordLube:add')" )
    ////@Log(title = "润滑记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsRecordLube dmsRecordLube)
    {
        return toAjax(dmsRecordLubeService.insertDmsRecordLube(dmsRecordLube));
    }

    /**
     * 修改润滑记录
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsRecordLube:edit')" )
    ////@Log(title = "润滑记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsRecordLube dmsRecordLube)
    {
        return toAjax(dmsRecordLubeService.updateDmsRecordLube(dmsRecordLube));
    }

    /**
     * 删除润滑记录
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsRecordLube:remove')" )
    ////@Log(title = "润滑记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{recordLubeIds}")
    public AjaxResult remove(@PathVariable Long[] recordLubeIds)
    {
        return toAjax(dmsRecordLubeService.deleteDmsRecordLubeByRecordLubeIds(recordLubeIds));
    }
}
